@@ -218,7 +218,7 @@ github_project_url = "https://github.com/matplotlib/matplotlib/"
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
 #html_style = 'matplotlib.css'
-html_style = 'mpl.css'
+html_style = f'mpl.css?{SHA}'
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
@@ -249,10 +249,9 @@ html_index = 'index.html'
 
 # Custom sidebar templates, maps page names to templates.
 html_sidebars = {
-    'index': ['searchbox.html', 'sidebar_announcement.html',
+    'index': ['sidebar_announcement.html', 'sidebar_versions.html',
               'donate_sidebar.html'],
-    '**': ['searchbox.html', 'localtoc.html', 'relations.html',
-           'pagesource.html']
+    '**': ['localtoc.html', 'relations.html', 'pagesource.html']
 }
 
 # If false, no module index is generated.
